@@ -1,10 +1,12 @@
 #ifndef TEST_HPP
 #define TEST_HPP
 
-#include <catch.hpp>
+#include <catch.hpp> // IWYU pragma: export
 
-#include <array>
-#include <vector>
+#include <array> // IWYU pragma: export
+#include <limits> // IWYU pragma: export
+#include <string> // IWYU pragma: export
+#include <vector> // IWYU pragma: export
 
 #include <stdexcept>
 // Define protozero_assert() to throw this error. This allows the tests to
@@ -13,12 +15,12 @@ struct assert_error : public std::runtime_error {
     explicit assert_error(const char* what_arg) : std::runtime_error(what_arg) {
     }
 };
-#define protozero_assert(x) if (!(x)) { throw assert_error{#x}; }
+#define protozero_assert(x) if (!(x)) { throw assert_error{#x}; } // NOLINT(readability-simplify-boolean-expr)
 
-#include <protozero/pbf_builder.hpp>
-#include <protozero/pbf_message.hpp>
-#include <protozero/pbf_reader.hpp>
-#include <protozero/pbf_writer.hpp>
+#include <protozero/pbf_builder.hpp> // IWYU pragma: export
+#include <protozero/pbf_message.hpp> // IWYU pragma: export
+#include <protozero/pbf_reader.hpp> // IWYU pragma: export
+#include <protozero/pbf_writer.hpp> // IWYU pragma: export
 
 extern std::string load_data(const std::string& filename);
 
