@@ -2,10 +2,10 @@
 #include <test.hpp>
 
 TEST_CASE("default constructed varint_iterators are equal") {
-    protozero::const_varint_iterator<uint32_t> a{};
-    protozero::const_varint_iterator<uint32_t> b{};
+    const protozero::const_varint_iterator<uint32_t> a{};
+    const protozero::const_varint_iterator<uint32_t> b{};
 
-    protozero::iterator_range<protozero::const_varint_iterator<uint32_t>> r{};
+    const protozero::iterator_range<protozero::const_varint_iterator<uint32_t>> r{};
 
     REQUIRE(a == a);
     REQUIRE(a == b);
